View Source Membrane.UDP.Sink (Membrane UDP plugin v0.9.2)
Element that sends buffers received on the input pad over a UDP socket.
element-options
Element options
Passed via struct Membrane.UDP.Sink.t/0
destination_address:inet.ip_address()Required
An IP Address that the packets will be sent to.destination_port_no:inet.port_number()Required
A UDP port number of a target.local_address:inet.socket_address()Default value:
:any
An IP Address set for a UDP socket used to sent packets. It allows to specify which network interface to use if there's more than one.local_port_no:inet.port_number()Default value:
0
A UDP port number for the socket used to sent packets. If set to0(default) the underlying OS will assign a free UDP port.
pads
Pads
input
:input
| Accepted formats |
|
| Availability | :always |
| Demand mode | :manual |
| Demand unit | :buffers |
| Direction | :input |
| Mode | :pull |
| Name | :input |
Link to this section Summary
Types
Struct containing options for Membrane.UDP.Sink
Link to this section Types
@type t() :: %Membrane.UDP.Sink{ destination_address: :inet.ip_address(), destination_port_no: :inet.port_number(), local_address: :inet.socket_address(), local_port_no: :inet.port_number() }
Struct containing options for Membrane.UDP.Sink
Link to this section Functions
@spec options() :: keyword()
Returns description of options available for this module